"""这是nester模块,提供了一个名为print_lol()的函数.
这个函数的作用是打印列表,其中可能包含(也可能不包含)嵌套列表.
"""


def print_lol(the_list):
    """
    :param the_list: 这个位置参数可以是python列表(也可以是嵌套列表的列表).
    :return: 所指定的列表中的每一个数据项会(递归地)输出到屏幕上,各数据项各占一行.
    """
    for each_line in the_list:
        if isinstance(each_item, list):
            print_lol(each_item)
        else:
            print(each_line)



from distutils.core import setup


setup(
    name='hp_nester',
    version='1.0.0',
    py_modules=['nester'],
    author='How Peng',
    author_email='howpeng@foxmail.com',
    url='http://howpeng.com',
    description='A simple printer of nested lists.',
)